addTo method

void addTo(
  1. Scene scene
)

Puts the ground, the crowd and the fog into scene, and keeps it for the buildings that arrive later.

Implementation

void addTo(Scene scene) {
  _scene = scene;
  scene
    ..add(_ground)
    ..add(_crowd);
  final InstancedMeshNode? unseen = _unseen;
  final InstancedMeshNode? remembered = _remembered;
  if (unseen != null) scene.add(unseen);
  if (remembered != null) scene.add(remembered);
}